/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * ***** END LICENSE BLOCK ***** */

/**
Creates a Tags-view object.

@constructor
@param {Boolean} active
@param {String} id
@param {String} defaultHref
*/
function MozileTags( active, id, defaultHref ) {
	this.active = active || false;
	this.id = id;                    // id of the link element.
	this.defaultHref = defaultHref;  // default url of Tag-view css file. 
}


/**
Creates a link to the Tag-view stylesheet, or removes it.

<p>The default XHTML style sheet highlights XHTML tags.
<p>An alternate style sheet (e.g. for XML files) can be specified via the RSD configuration file.

@param {Window} target
@param {String} tagRef - url of CSS file, "XHTML" or <code>false</code> to use defaultHref.
*/
MozileTags.prototype.toggle = function(target, tagRef) {
	var f = ["mozileTags.js","toggle"];

	if (!target) {
		target = document.commandDispatcher.focusedWindow;
	} else if (target != document.commandDispatcher.focusedWindow) {
		return;
	}

	if ( !mozileIsLoaded( target ) ) {
		return;
	}

	var targetDoc = target.document;
	var head = targetDoc.getElementsByTagName("head")[0];
	var link = targetDoc.getElementById(this.id);

	var href;
	if(tagRef=="XHTML" || !tagRef ) {
		href = this.defaultHref;
	} else {
		href = tagRef;
	}
	
	if(!head) {
		head = targetDoc.documentElement;
		mozile.bug.write(f,2,"Document element: "+head.tagName);
	}

	if(link) {
		head.removeChild(link);
		this.active = false;
		mozile.bug.write(f,2,"Hide tags");
	} else {
		link = document.createElementNS("http://www.w3.org/1999/xhtml","link");
		link.id = this.id;
		link.setAttribute("rel","stylesheet");
		link.setAttribute("type","text/css");
		link.setAttribute("href",href);
		head.appendChild(link);
		this.active = true;
		mozile.bug.write(f,2,"Show tags");
	}
};

/**
Removes the Tag-view stylesheet link.

@param {Window} target
*/
MozileTags.prototype.unload = function(target) {
	var link = target.document.getElementById(this.id);
	if (link) {
		link.parentNode.removeChild(link);
	}
};
